@@ -8,7 +8,7 @@ import enum
 class FunctionTemplateParams:
     """
     Standardises which paramters need to be passed
-    to render a 'function' template
+    to render a 'function'template
     """
     function_name: str
     function_body: str 
@@ -18,5 +18,7 @@ class MetaDictionary(enum.Enum):
     this are the keywork that we map every
     wrapper to for translationj
     """
-    RECEIVED_MESSAGE = 'This is the input message string for the bot function'
-    SEND_MESSAGE = 'This is the method to send a message as reply'
+    RECEIVED_MESSAGE = 'input message string for the bot function'
+    SEND_MESSAGE = 'method to send a message as reply'
+    CHAT = 'chat object'
+    USER_SENDER = 'user object who sent the message'
